@@ -1,3 +1,3 @@
 from .core import route
 
-__all__ = 'route'
+__all__ = "route"
