@@ -19,10 +19,11 @@ async def make_request(
     data = create_dict_if_not(data=data)
     query = create_dict_if_not(data=query)
 
-    with async_timeout.timeout(delay=timeout):
+    async with async_timeout.timeout(delay=timeout):
         async with aiohttp.ClientSession(headers=headers) as session:
             async with session.request(
-                    method=method, url=url, params=query, data=data) as response:
+                method=method, url=url, params=query, data=data
+            ) as response:
                 response_json = await response.json()
                 decoded_json = decode_json(data=response_json)
                 return decoded_json, response.status, response.headers
